@@ -1,3 +1,4 @@
+use std::error;
 use std::ffi::NulError;
 use std::fmt;
 
@@ -8,6 +9,8 @@ pub enum Error {
     Unknown
 }
 
+impl error::Error for Error {}
+
 impl fmt::Display for Error {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         match *self {
